from setuptools import setup, find_packages

setup(
    name='mydatatest',
    version='0.1',
    description='A simple Python library for calculating the area of geometric shapes.',
    author='Diwakar Patel',
    packages=find_packages(),
)